import 'package:flutter/material.dart';
import 'package:flutter_iiif/flutter_iiif.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter IIIFImage Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: IIIFDemo(),
    );
  }
}

class IIIFDemo extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _IIIFDemoState();
  }
}

class _IIIFDemoState extends State {
  /// Some info for testing
  final String server = 'http://mfn0006.naturkundemuseum-berlin.de:3200/api/v1/iiif/';
  final List<String> assets = ['3745679'];
  final List<String> qualities = ['default.jpg', 'colorize.jpg', 'gray.jpg', 'bitonal.jpg'];
  final List<double> tileSizes = [56.0, 128.0, 256.0, 512.0];

  /// POPUP Menus
  List<PopupMenuItem<String>> imagePopupItems = [];
  List<PopupMenuItem<String>> qualityPopupItems = [];
  List<PopupMenuItem<double>> tileSizePopupItems = [];

  IIIFImage iiif;
  IIIFImageSettings settings;

  /// Demo State Constructor
  _IIIFDemoState() {
    settings = IIIFImageSettings(server: server, assetID: assets[0], quality: qualities[0]);
    iiif = IIIFImage(settings: settings);

    /// create image picker
    assets.forEach((String str) {
      imagePopupItems.add(PopupMenuItem<String>(
        value: str,
        child: Text('image: ${imagePopupItems.length + 1}'),
      ));
    });

    /// create qualities picker
    qualities.forEach((String str) {
      qualityPopupItems.add(PopupMenuItem<String>(
        value: str,
        child: Text(str),
      ));
    });

    /// create tileSize picker
    tileSizes.forEach((double i) {
      tileSizePopupItems.add(PopupMenuItem<double>(
        value: i,
        child: Text('$i x $i'),
      ));
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Stack(children: [
        /// The Image
        iiif,

        /// Interaction menu
        Column(
          children: <Widget>[
            /// choose image
            Row(children: [
              PopupMenuButton(
                  icon: Icon(Icons.image),
                  onSelected: (String str) {
                    setState(() {
                      settings.assetID = str;
                      settings.notifier.notifyListeners();
                    });
                  },
                  itemBuilder: (BuildContext context) => imagePopupItems),
              Text(settings.assetID)
            ]),

            /// choose quality
            Row(children: [
              PopupMenuButton(
                  icon: Icon(Icons.filter),
                  onSelected: (String str) {
                    setState(() {
                      settings.quality = str;
                      settings.notifier.notifyListeners();
                    });
                  },
                  itemBuilder: (BuildContext context) => qualityPopupItems),
              Text(settings.quality)
            ]),

            // choose quality
            Row(children: [
              PopupMenuButton(
                  icon: Icon(Icons.grid_on),
                  onSelected: (double n) {
                    setState(() {
                      settings.tileSize = n;
                      settings.notifier.notifyListeners();
                    });
                  },
                  itemBuilder: (BuildContext context) => tileSizePopupItems),
              Text('${settings.tileSize} x ${settings.tileSize}')
            ])
          ],
        ),
      ]),
    );
  }
}
