import 'package:flutter/material.dart';
import 'package:vector_math/vector_math_64.dart' show Vector3;
import 'dart:math' show min;
import 'IIIFImageSettings.dart';

class IIIFTile extends StatelessWidget {
  //
  //
  final double x;
  final double y;
  final double rawTileSize;
  final IIIFImageSettings settings;
  final double scale;
  final Vector3 translation;
  IIIFTile({Key key, this.x, this.y, this.settings, this.rawTileSize, this.scale, this.translation}) : super(key: key);
  //
  //
  final double padding = 0;
  //
  //

  factory IIIFTile.validate({double x, double y, IIIFImageSettings settings, double rawTileSize, double scale, Vector3 translation}) {
    IIIFTile tile;
    if (x * rawTileSize < settings.meta.width && y * rawTileSize < settings.meta.height) {
      tile = new IIIFTile(x: x, y: y, settings: settings, rawTileSize: rawTileSize, scale: scale, translation: translation);
    }
    return tile;
  }

  String url(double left, double top, double width, double height) {
    return settings.server +
        //
        '${settings.assetID}/' +
        //
        '${left.round()},${top.round()},${width.round()},${height.round()}/' +
        //
        '${settings.tileSize.round()},${settings.tileSize.round()}/' +
        //
        '0/' +
        //
        settings.quality;
  }

  @override
  Widget build(BuildContext context) {
    //
    //
    double left = x * rawTileSize;
    double top = y * rawTileSize;
    double imageWidth = min(rawTileSize, settings.meta.width - left) + 1;
    double imageHeight = min(rawTileSize, settings.meta.height - top) + 1 * (settings.meta.width / settings.meta.height);
    //
    //
    double containerWidth = (settings.tileSize - padding) * (imageWidth / rawTileSize);
    double containerHeight = (settings.tileSize - padding) * (imageHeight / rawTileSize);
    //
    //
    Matrix4 transformation = Matrix4.identity();
    transformation.translate(translation.x, translation.y);
    transformation.scale(scale);
    transformation.translate(x * settings.tileSize, y * settings.tileSize);
    //
    print('$x $y ${imageWidth.floor()} , ${imageHeight.floor()}  => ${containerWidth.floor()} , ${containerHeight.floor()}');
    print(url(left, top, imageWidth, imageHeight));
    //
    return Container(
      width: containerWidth,
      height: containerHeight,
      color: (x % 2 == y % 2) ? Colors.red : Colors.blue,
      transform: transformation,
      child: Image.network(
        url(left, top, imageWidth, imageHeight),
        alignment: Alignment.topLeft,
      ),
    );
  }
}
